@@ -49,6 +49,9 @@
 #define BARCODE_TYPE_QRCODE   3
 #define BARCODE_TYPE_PDF417   4
 
+#define MAX_VIDEO_WIDTH   800
+#define MAX_VIDEO_HEIGHT  480
+
 #define WIDTH   400
 #define HEIGHT  240
 
