@@ -42,6 +42,7 @@
 #include <QFileDialog>
 #include <QFileInfo>
 
+#include <iostream>
 
 // gstreamer includes
 #include <gst/gst.h>
@@ -63,6 +64,8 @@
 #include "pluginloaderthread.h"
 #include <cmath>
 
+using namespace std;
+
 extern QTime debugSpeedTimer;
 
 
@@ -364,7 +367,7 @@ void MaemoBarcodeWindow::loadPlugins() {
     //QList<bool> origPluginPresent;
 
     int numPlugins = settings->beginReadArray("plugins");
-    qDebug() << "loadPlugins(): Loading plugin info, found " << numPlugins;
+    cout << "loadPlugins(): Loading plugin info, found " << QString("%1").arg(numPlugins).toStdString() << endl;
 
     //int max_pri=-1;
     //int pri;
@@ -395,14 +398,17 @@ void MaemoBarcodeWindow::loadPlugins() {
     this->NumEnabledPlugins=0;
 
     foreach (QString fileName, allPluginFiles) { // go through all files in the plugin dir
-        qDebug(qPrintable("Loading " + fileName));
+        cout << "Loading " << fileName.toStdString() << endl;
+
         QPluginLoader loader(fileName); // create a loader for the shared library
         QObject *plugin = loader.instance();  // load it as a QObject
         if (plugin) { // if it is a plugin (this fails if virtual functions are not implemented correct)
-            qDebug(qPrintable("Loaded successfully: " + fileName));
+            cout << "Loaded successfully: " << fileName.toStdString() << endl;
+
             pluginFileNames += fileName; // list all our plugin file names
             PluginInterface* interface = qobject_cast<PluginInterface*>(plugin); // cast it to our kind of interface
-            qDebug(qPrintable("Interface name: " + interface->getName()));
+            cout << "Interface name: " << interface->getName().toStdString() << endl;
+
             pluginInterfaces.append(interface); // add this interface to our list of interfaces
             interface->initInterface(this); // initialize the plugin
             foreach(PluginAction* pluginAction, interface->getPluginActions()) { // get the list of sink plugins in the interface
@@ -418,7 +424,7 @@ void MaemoBarcodeWindow::loadPlugins() {
                     //pluginAction->setPriority(origPluginPriorities.value(ind));
                     pluginAction->setEnabled(origPluginEnabled.value(ind));
 
-                    qDebug() << "loadPlugins(): Found plugin listed in settings " << pluginIdentifier << pluginAction->getEnabled();
+                    cout << "loadPlugins(): Found plugin listed in settings " << pluginIdentifier.toStdString() << QString("%1").arg(pluginAction->getEnabled()).toStdString() << endl;
 
                 }else{
                     // no we don't know about this one
@@ -427,7 +433,7 @@ void MaemoBarcodeWindow::loadPlugins() {
                     pluginAction->setEnabled(true);
 
                     //qDebug() << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier << " " << max_pri << " true";
-                    qDebug() << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier << " true";
+                    cout << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier.toStdString() << " true" << endl;
                 }
 
                 if (pluginAction->getEnabled())
@@ -437,7 +443,7 @@ void MaemoBarcodeWindow::loadPlugins() {
             }
             qApp->processEvents();
         } else {
-            qWarning(qPrintable("loadPlugins(): Could not load: " + fileName + " due to error: " + loader.errorString()));
+            cout << "loadPlugins(): Could not load: " << fileName.toStdString() << " due to error: " << loader.errorString().toStdString() << endl;
         }
     }
 
