@@ -93,6 +93,12 @@ public:
     bool continuousScanningMode;
     bool AutoUseFirstPlugin;
 
+    QList<QString> pluginNames;
+    QList<unsigned char> pluginPriorities;
+    QList<bool> pluginEnabled;
+
+    int NumEnabledPlugins;
+
 signals:
     Q_SCRIPTABLE void barcodeAnalysedSignal(QString barcodeType, QString barcodeData);
     void dataAnalysedSignal(QString dataType, QString barcodeData, QHash<QString, QString> data);
@@ -106,6 +112,7 @@ public slots:
     void showResultsWindow(QString barcode);
     void showSettingsWindow();
     void OpenAndScanImage();
+    void analyseImageSyncCallBack();
 
     //Q_SCRIPTABLE int register_external_plugin(QString appname, QString dbus_command_to_call, QString RequiredBarcodeTypes);
 protected:
@@ -128,6 +135,7 @@ private:
     bool secondChangeEvent;
     bool lensCoverOpen;
 
+    uchar* imageBuffer;
 
 
     //PluginLoaderThread *pluginloaderthread;
