@@ -39,6 +39,7 @@
 // local includes
 
 class PluginAction;
+class MaemoBarcodeWindow;
 
 namespace Ui {
     class ResultsWindow;
@@ -57,6 +58,7 @@ public slots:
 private:
     QList<PluginAction *> plugin_list;
 };
+
 class PluginActionListDelegate : public QStyledItemDelegate {
 Q_OBJECT
 
@@ -68,10 +70,11 @@ void paint(QPainter *painter, const QStyleOptionViewItem &option,
            const QModelIndex &index) const;
 QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index);
 };
+
 class ResultsWindow : public QMainWindow {
     Q_OBJECT
 public:
-    ResultsWindow(QWidget *parent = 0);
+    ResultsWindow(MaemoBarcodeWindow *parent = 0);
     ~ResultsWindow();
 
     void processBarcode(QString barcode);
@@ -92,6 +95,7 @@ private:
     QTimer *selectionTimer;
 
     int PluginUpdateCounter;
+    MaemoBarcodeWindow *parent;
 
 private slots:
     void on_tblResults_clicked(QModelIndex index);
