@@ -68,7 +68,7 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     setAutoBufferSwap(false);
     frame_width = WIDTH;
     frame_height = HEIGHT; // 300x160 should be the correct aspect ratio
-    decoder->setFrameSize(frame_width, frame_height);
+    //decoder->setFrameSize(frame_width, frame_height);
     cold_start = true;
     appSinkScanning = false;
     QApplication::syncX();
@@ -109,8 +109,8 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     imgRecent = imgRecent.scaledToWidth(48, Qt::SmoothTransformation);
     imgSettings = QImage(":/images/gui/settings.png");
     imgSettings = imgSettings.scaledToWidth(48, Qt::SmoothTransformation);
-//    imgOpen = QImage(":/images/gui/settings.png");
-//    imgOpen = imgOpen.scaledToWidth(48, Qt::SmoothTransformation);
+    imgOpen = QImage(":/images/gui/task-manager.png");
+    imgOpen = imgOpen.scaledToWidth(48, Qt::SmoothTransformation);
 
     qDebug() << "VideoWidget::VideoWidget(): Setting up frame counts";
     // timer, should be set last, just in case
@@ -149,7 +149,7 @@ void VideoWidget::resizeGL(int w, int h) {
     }
     imgRecentPos = QPoint(w - imgRecent.width() - 15, imgSavePos.y() + imgSave.height() + 30);
     imgSettingsPos = QPoint(w - imgSettings.width() - 15, imgRecentPos.y() + imgRecent.height() + 30);
-//    imgOpenPos = QPoint(w - imgOpen.width() - 15, imgSettingsPos.y() + imgSettings.height() + 30);
+    imgOpenPos = QPoint(w - imgOpen.width() - 15, imgSettingsPos.y() + imgSettings.height() + 30);
     // task manager button
     imgTaskManagerPos = QPoint(25, 10);
 }
@@ -403,7 +403,7 @@ void VideoWidget::paintGL() {
     painter.drawImage(imgSavePos, imgSave);
     painter.drawImage(imgRecentPos, imgRecent);
     painter.drawImage(imgSettingsPos, imgSettings);
-//    painter.drawImage(imgOpenPos, imgOpen);
+    painter.drawImage(imgOpenPos, imgOpen);
 
     // draw info
     QPen halfTransparentPen;
@@ -535,11 +535,11 @@ bool VideoWidget::initPipeline() {
     else
         qDebug() << "VideoWidget::initPipeline(): camera_src is now loaded";
 
-    qDebug() << "VideoWidget::initPipeline(): Setting file source";
-    file_src = gst_element_factory_make("filesrc", "file_src");
+    //qDebug() << "VideoWidget::initPipeline(): Setting file source";
+    //file_src = gst_element_factory_make("filesrc", "file_src");
     //useFilesrc("/usr/share/icons/hicolor/14x14/hildon/general_alarm_on.png"); // dummy file to do a quickfix
-    qDebug() << "VideoWidget::initPipeline(): Setting input selector";
-    input_selector = gst_element_factory_make("input-selector", "input_selector");
+    //qDebug() << "VideoWidget::initPipeline(): Setting input selector";
+    //input_selector = gst_element_factory_make("input-selector", "input_selector");
     //    g_object_set(G_OBJECT(input_selector), "n-pads", 2, NULL); // set 2 input pads
 
     /* Colorspace filter is needed to make sure that sinks understands
@@ -554,10 +554,10 @@ bool VideoWidget::initPipeline() {
     image_filter = gst_element_factory_make("ffmpegcolorspace", "image_filter");
 
     video_crop = gst_element_factory_make ("videocrop", "videocrop");
-    g_object_set (G_OBJECT (video_crop), "bottom", frame_height / 2, NULL);
-    g_object_set (G_OBJECT (video_crop), "left", frame_width / 2, NULL);
-    g_object_set (G_OBJECT (video_crop), "right", frame_width / 2, NULL);
-    g_object_set (G_OBJECT (video_crop), "top", frame_height / 2, NULL);
+    g_object_set (G_OBJECT (video_crop), "bottom", frame_height/2, NULL);
+    g_object_set (G_OBJECT (video_crop), "left", frame_width/2, NULL);
+    g_object_set (G_OBJECT (video_crop), "right", frame_width/2, NULL);
+    g_object_set (G_OBJECT (video_crop), "top", frame_height/2, NULL);
 
     /* Queue creates new thread for the stream */
     screen_queue = gst_element_factory_make ("queue", "screen_queue");
@@ -794,7 +794,7 @@ gboolean VideoWidget::bufferProbeCallback (char *data) {
 //        *(dst++) = (*(src++));
 //    } while (--z);
 
-    type = decoder->analyseImage(data, fourcc, bpp); // type is ignored anyway
+    type = decoder->analyseImage(data, frame_width, frame_height, fourcc, bpp); // type is ignored anyway
 
     /* Returning TRUE means that the buffer can is OK to be
      * sent forward. When using fakesink this doesn't really
@@ -919,11 +919,11 @@ void VideoWidget::mousePressEvent(QMouseEvent *event){
     if(imgRect.contains(event->pos())) { // see whether the click hit this rectangle
         parent->showSettingsWindow();
     }
-//    imgRect = QRect(imgOpenPos, imgOpen.size()); // get the rectangle surrounding the image
-//    imgRect.adjust(-10,-10,10,10); // make the hit rectangle a bit larger
-//    if(imgRect.contains(event->pos())) { // see whether the click hit this rectangle
-//        parent->OpenAndScanImage();
-//    }
+    imgRect = QRect(imgOpenPos, imgOpen.size()); // get the rectangle surrounding the image
+    imgRect.adjust(-10,-10,10,10); // make the hit rectangle a bit larger
+    if(imgRect.contains(event->pos())) { // see whether the click hit this rectangle
+        parent->OpenAndScanImage();
+    }
 }
 
 void VideoWidget::startTimedScan(int time)
